==> mapmyindia_gl-0.2.1.tar.gz: example/lib/samples/style_widget.dart <==
import 'dart:typed_data';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:mapmyindia_gl/mapmyindia_gl.dart';
import 'package:mapmyindia_gl_example/utils/color.dart';

class StyleWidget extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return StyleWidgetState();
  }
}

class StyleWidgetState extends State {
  static final CameraPosition _kInitialPosition = const CameraPosition(
    target: LatLng(25.321684, 82.987289),
    zoom: 10.0,
  );

  bool isMapLoaded = false;

  String? style;
  bool isSelectedLastStyle = false;

  late MapmyIndiaMapController controller;

  @override
  void initState() {
    super.initState();
    setSelectedLastStyle();
  }

  setSelectedLastStyle() async {
    bool isSelected =
        await MapmyIndiaMapConfiguration.isShowLastSelectedStyle();
    setState(() {
      isSelectedLastStyle = isSelected;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        centerTitle: true,
        backgroundColor: MyColor.colorPrimary,
        brightness: Brightness.dark,
        title: Text(
          'Map Style',
          style: TextStyle(color: Colors.white),
        ),
        elevation: 0.2,
      ),
      body: Column(children: [
        Expanded(
            child: MapmyIndiaMap(
          initialCameraPosition: _kInitialPosition,
          mapmyIndiaStyle: style,
          onMapError: (code, message) => {print('$code -------- $message')},
          onMapCreated: (map) => {
            print("onMapCreated"),
            controller = map,
            setState(() {
              isMapLoaded = true;
            })
          },
          onStyleLoadedCallback: () => {addMarker()},
          annotationOrder: [
            AnnotationType.fill,
            AnnotationType.circle,
            AnnotationType.line,
            AnnotationType.symbol,
          ],
        )),
        isMapLoaded
            ? Row(

            children: [
                Checkbox(
                        value: isSelectedLastStyle,
                        onChanged: (isCheck) async {
                          await MapmyIndiaMapConfiguration
                              .setShowLastSelectedStyle(isCheck!);
                          setSelectedLastStyle();
                        }),
                SizedBox(width: 4,),
                Text("Show Last Selected Style")
              ])
            : Container(),
        isMapLoaded
            ? TextButton(
                onPressed: () {
                  showStylesList();
                },
                child: Text(
                  "Show Style List",
                  style: TextStyle(color: Colors.white),
                ),
                style: TextButton.styleFrom(
                    backgroundColor: MyColor.colorPrimaryDark,
                    textStyle: TextStyle(color: Colors.white)),
              )
            : Container()
      ]),
    );
  }

  /// Adds an asset image to the currently displayed style
  Future<void> addImageFromAsset(String name, String assetName) async {
    final ByteData bytes = await rootBundle.load(assetName);
    final Uint8List list = bytes.buffer.asUint8List();
    return controller.addImage(name, list);
  }

  void addMarker() async {
    await addImageFromAsset("icon", "assets/symbols/custom-icon.png");
    controller.addSymbol(SymbolOptions(
        geometry: LatLng(25.321684, 82.987289),
        draggable: true,
        iconImage: 'icon'));
    controller.setSymbolIconIgnorePlacement(false);
    controller.setSymbolIconAllowOverlap(true);
    print(await controller.getMapmyIndiaStyle());
  }

  showStylesList() async {
    List<MapmyIndiaStyle> mapmyIndiaStyles =
        await controller.getMapmyIndiaAvailableStyles();
    showModalBottomSheet(
      context: context,
      builder: (context) {
        return Expanded(
            child: ListView.builder(
                itemCount: mapmyIndiaStyles.length,
                itemBuilder: (context, index) {
                  return Container(
                      padding: EdgeInsets.fromLTRB(12, 0, 12, 0),
                      decoration: BoxDecoration(
                          color: Colors.white,
                          border: Border(bottom: BorderSide())),
                      child: ListTile(
                        contentPadding: EdgeInsets.all(5),
                        focusColor: Colors.white,
                        title: Text(mapmyIndiaStyles[index].displayName ?? ''),
                        subtitle: Text(
                          mapmyIndiaStyles[index].description ?? '',
                          maxLines: 2,
                        ),
                        onTap: () {
                          setState(() {
                            style = mapmyIndiaStyles[index].name;
                          });
                        },
                      ));
                }));
      },
    );
  }
}

==> mapmyindia_gl-0.3.2.tar.gz: example/lib/samples/style_widget.dart <==
import 'dart:typed_data';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:mapmyindia_gl/mapmyindia_gl.dart';
import 'package:mapmyindia_gl_example/utils/color.dart';

class StyleWidget extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return StyleWidgetState();
  }
}

class StyleWidgetState extends State {
  static final CameraPosition _kInitialPosition = const CameraPosition(
    target: LatLng(25.321684, 82.987289),
    zoom: 10.0,
  );

  bool isMapLoaded = false;

  String? style;
  bool isSelectedLastStyle = false;

  late MapmyIndiaMapController controller;

  @override
  void initState() {
    super.initState();
    setSelectedLastStyle();
  }

  setSelectedLastStyle() async {
    bool isSelected =
        await MapmyIndiaMapConfiguration.isShowLastSelectedStyle();
    setState(() {
      isSelectedLastStyle = isSelected;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        centerTitle: true,
        backgroundColor: MyColor.colorPrimary,
        brightness: Brightness.dark,
        title: Text(
          'Map Style',
          style: TextStyle(color: Colors.white),
        ),
        elevation: 0.2,
      ),
      body: Column(children: [
        Expanded(
            child: MapmyIndiaMap(
          initialCameraPosition: _kInitialPosition,
          mapmyIndiaStyle: style,
          onMapError: (code, message) => {print('$code -------- $message')},
          onMapCreated: (map) => {
            print("onMapCreated"),
            controller = map,
          controller.enableTraffic(true),
          setState(() {
              isMapLoaded = true;
            })
          },
          onStyleLoadedCallback: () => {addMarker()},
          annotationOrder: [
            AnnotationType.fill,
            AnnotationType.circle,
            AnnotationType.line,
            AnnotationType.symbol,
          ],
        )),
        isMapLoaded
            ? Row(

            children: [
                Checkbox(
                        value: isSelectedLastStyle,
                        onChanged: (isCheck) async {
                          await MapmyIndiaMapConfiguration
                              .setShowLastSelectedStyle(isCheck!);
                          setSelectedLastStyle();
                        }),
                SizedBox(width: 4,),
                Text("Show Last Selected Style")
              ])
            : Container(),
        isMapLoaded
            ? TextButton(
                onPressed: () {
                  showStylesList();
                },
                child: Text(
                  "Show Style List",
                  style: TextStyle(color: Colors.white),
                ),
                style: TextButton.styleFrom(
                    backgroundColor: MyColor.colorPrimaryDark,
                    textStyle: TextStyle(color: Colors.white)),
              )
            : Container()
      ]),
    );
  }

  /// Adds an asset image to the currently displayed style
  Future<void> addImageFromAsset(String name, String assetName) async {
    final ByteData bytes = await rootBundle.load(assetName);
    final Uint8List list = bytes.buffer.asUint8List();
    return controller.addImage(name, list);
  }

  void addMarker() async {
    print("ON Style Loaded");

    await addImageFromAsset("icon", "assets/symbols/custom-icon.png");
    controller.addSymbol(SymbolOptions(
        geometry: LatLng(25.321684, 82.987289),
        draggable: true,
        iconImage: 'icon'));
    controller.setSymbolIconIgnorePlacement(false);
    controller.setSymbolIconAllowOverlap(true);
    // controller.enableTrafficClosure(true);
    // print(await controller.getMapmyIndiaStyle());
  }

  showStylesList() async {
    List<MapmyIndiaStyle> mapmyIndiaStyles =
        await controller.getMapmyIndiaAvailableStyles();
    showModalBottomSheet(
      context: context,
      builder: (context) {
        return Expanded(
            child: ListView.builder(
                itemCount: mapmyIndiaStyles.length,
                itemBuilder: (context, index) {
                  return Container(
                      padding: EdgeInsets.fromLTRB(12, 0, 12, 0),
                      decoration: BoxDecoration(
                          color: Colors.white,
                          border: Border(bottom: BorderSide())),
                      child: ListTile(
                        contentPadding: EdgeInsets.all(5),
                        focusColor: Colors.white,
                        title: Text(mapmyIndiaStyles[index].displayName ?? ''),
                        subtitle: Text(
                          mapmyIndiaStyles[index].description ?? '',
                          maxLines: 2,
                        ),
                        onTap: () {
                          setState(() {
                            style = mapmyIndiaStyles[index].name;
                          });
                        },
                      ));
                }));
      },
    );
  }
}
